"""
Brain-Striatum Segmentation Package
"""

__version__ = "1.0.0"
__author__ = "BongIl Song & Yeaeun Song" 

from .python_api import brain_striatum_segmentation

__all__ = ["brain_striatum_segmentation"]

print(f"\n🧠 Brain-Striatum Segmentation v{__version__}")
print("If you use this tool please cite our paper: [Your Citation]")
print("Please also cite nnUNet: https://github.com/MIC-DKFZ/nnUNet\n")